@@ -2,17 +2,12 @@ import json
 from pathlib import Path
 from typing import Optional
 
+from jupyter_server.auth.decorator import authorized
+from jupyter_server.base.handlers import APIHandler
 from tornado import web
 
 from .base import TerminalsMixin
 
-try:
-    from jupyter_server.auth import authorized
-    from jupyter_server.base.handlers import APIHandler
-except ModuleNotFoundError:
-    raise ModuleNotFoundError("Jupyter Server must be installed to use this extension.")
-
-
 AUTH_RESOURCE = "terminals"
 
 
@@ -60,7 +55,7 @@ class TerminalRootHandler(TerminalsMixin, TerminalAPIHandler):
 
 
 class TerminalHandler(TerminalsMixin, TerminalAPIHandler):
-    SUPPORTED_METHODS = ("GET", "DELETE")
+    SUPPORTED_METHODS = ("GET", "DELETE")  # type:ignore[assignment]
 
     @web.authenticated
     @authorized
