@@ -3,18 +3,14 @@ import shlex
 import sys
 from shutil import which
 
+from jupyter_core.utils import ensure_async
+from jupyter_server.extension.application import ExtensionApp
+from jupyter_server.transutils import trans
 from traitlets import Type
 
 from . import api_handlers, handlers
 from .terminalmanager import TerminalManager
 
-try:
-    from jupyter_server.extension.application import ExtensionApp
-    from jupyter_server.transutils import trans
-    from jupyter_server.utils import run_sync_in_loop
-except ModuleNotFoundError:
-    raise ModuleNotFoundError("Jupyter Server must be installed to use this extension.")
-
 
 class TerminalsExtensionApp(ExtensionApp):
 
@@ -35,7 +31,9 @@ class TerminalsExtensionApp(ExtensionApp):
 
     def initialize_settings(self):
         self.initialize_configurables()
-        self.settings.update(dict(terminals_available=True, terminal_manager=self.terminal_manager))
+        self.settings.update(
+            {"terminals_available": True, "terminal_manager": self.terminal_manager}
+        )
 
     def initialize_configurables(self):
         if os.name == "nt":
@@ -101,7 +99,7 @@ class TerminalsExtensionApp(ExtensionApp):
             "Shutting down %d terminal", "Shutting down %d terminals", n_terminals
         )
         self.log.info(terminal_msg % n_terminals)
-        await run_sync_in_loop(terminal_manager.terminate_all())
+        await ensure_async(terminal_manager.terminate_all())
 
     async def stop_extension(self):
         await self.cleanup_terminals()
